@@ -27,20 +27,22 @@ impl Client {
             Ok(host) => {
                 let (host, port) = host.split_once(":").unwrap();
                 tonic::transport::Uri::builder()
-                    .scheme("https")
+                    .scheme("http")
                     .authority(format!("{}:{}", host, port).as_str())
+                    .path_and_query("")
                     .build()
                     .unwrap()
             }
             Err(_) => tonic::transport::Uri::builder()
                 .scheme("https")
                 .authority(Self::DOMAIN_NAME)
+                .path_and_query("")
                 .build()
                 .unwrap(),
         };
         let tls_config = ClientTlsConfig::new()
             .ca_certificate(Certificate::from_pem(&pem))
-            .domain_name(Self::DOMAIN_NAME);
+            .domain_name(uri.host().unwrap());
         let channel = Channel::builder(uri)
             .tls_config(tls_config)?
             .connect()
