@@ -1,5 +1,6 @@
 mod certs;
 mod client;
+mod error;
 mod message;
 mod subscription;
 mod topic;
@@ -8,6 +9,7 @@ mod api {
 }
 
 pub use client::Client;
+pub use error::*;
 pub use message::Message;
 pub use subscription::Subscription;
 pub use topic::Topic;
